summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgameconnectdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgameconnectdialog.h')
-rw-r--r--libkdegames/kgame/dialogs/kgameconnectdialog.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libkdegames/kgame/dialogs/kgameconnectdialog.h b/libkdegames/kgame/dialogs/kgameconnectdialog.h
index ad4ff7d1..0a14183d 100644
--- a/libkdegames/kgame/dialogs/kgameconnectdialog.h
+++ b/libkdegames/kgame/dialogs/kgameconnectdialog.h
@@ -31,7 +31,7 @@ class KGameConnectWidget : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KGameConnectWidget(TQWidget* tqparent);
+ KGameConnectWidget(TQWidget* parent);
virtual ~KGameConnectWidget();
/**
@@ -109,8 +109,8 @@ private:
* @short Dialog to ask for host and port
*
* This Dialog is used to create a game. You call initConnection(port,
* TQString(), tqparent, true) to create a network game (as a server)
* or initConnection(port, host, tqparent) to join a network game.
*
* @author Andreas Beckermann <b_mann@gmx.de>
**/
@@ -119,7 +119,7 @@ class KGameConnectDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- KGameConnectDialog(TQWidget* tqparent = 0,int buttontqmask=Ok|Cancel);
+ KGameConnectDialog(TQWidget* parent = 0,int buttonmask=Ok|Cancel);
virtual ~KGameConnectDialog();
/**
@@ -128,11 +128,11 @@ public:
* @param port The port the user wants to connect to.
* @param host The host the user wants to connect to. Will be
* TQString() if server game is chosen
* @param tqparent The tqparent of the dialog
* @param server True to create a network game per default, false to
* join a game by default
**/
- static int initConnection(unsigned short int& port, TQString& host, TQWidget* tqparent, bool server = false);
+ static int initConnection(unsigned short int& port, TQString& host, TQWidget* parent, bool server = false);
/**
* @param host The host to connect to by default
@@ -109,8 +109,8 @@ private:
*
* This Dialog is used to create a game. You call initConnection(port,
- * TQString(), tqparent, true) to create a network game (as a server)
- * or initConnection(port, host, tqparent) to join a network game.
+ * TQString(), parent, true) to create a network game (as a server)
+ * or initConnection(port, host, parent) to join a network game.
*
* @author Andreas Beckermann <b_mann@gmx.de>
@@ -128,11 +128,11 @@ public:
* @param host The host the user wants to connect to. Will be
* TQString() if server game is chosen
- * @param tqparent The tqparent of the dialog
+ * @param parent The parent of the dialog
* @param server True to create a network game per default, false to
* join a game by default